@@ -63,6 +63,7 @@ my %Defaults = (
   mirrored => 0,
   count    => 0,
   interval => 0,
+  interval_randomized => 0,
 
   operator       => undef,
   source         => undef,
@@ -94,6 +95,7 @@ sub get_count    { shift->_opt->{count   } }
 sub get_interval { shift->_opt->{interval} }
 sub get_mirrored { shift->_opt->{mirrored} }
 sub get_debug    { shift->_opt->{debug   } }
+sub get_interval_randomized { shift->_opt->{interval_randomized} }
 
 sub get_filter_operator { shift->_opt->{filter_operator} }
 sub get_filter_source   { shift->_opt->{filter_source  } }
@@ -114,6 +116,12 @@ sub set_interval {
   $self->_xs->set_interval($self->_opt->{interval} = shift);
 }
 
+sub set_interval_randomized {
+  my $self = shift;
+  $self->_xs->set_interval_randomized(
+      $self->_opt->{interval_randomized} = shift);
+}
+
 sub set_debug {
   my $self = shift;
   $self->_xs->set_debug($self->_opt->{debug} = shift);
@@ -471,6 +479,11 @@ Stop processing after having written I<count> input messages to outputs
 
 Stop processing after I<interval> seconds have passed.
 
+=item interval_randomized
+
+Randomize the initial second within the defined I<interval>, rather than
+on the zeroth second of the interval.
+
 =item filter_vendor
 
 =item filter_msgtype
@@ -510,6 +523,10 @@ Specify a group filter for all inputs.
 
 =item get_interval()
 
+=item set_interval_randomized($mode)
+
+=item get_interval_randomized()
+
 =item set_filter_msgtype($vendor, $msgtype)
 
 =item get_filter_msgtype()
@@ -545,7 +562,7 @@ When invoked from a callback, causes the processing loop to halt.
 =item add_input($spec, %options)
 
 Add an input to the IO loop. A reasonable attempt is made to determine
-whether the specification is a file name (nmsg, pcap, pres), file handle
+whether the specification is a file name (nmsg, pcap), file handle
 (nmsg), channel alias or socket specification (nmsg), network device
 name (pcap), or reference to a Net::Nmsg::Input object, and is opened
 accordingly. If for some reason this reasonable guess is not so
