@@ -106,7 +106,9 @@ sub set_bpf     { shift->_set_io_opt(bpf     => @_) }
 ###
 
 sub is_file  { (shift->_xs || return)->is_file  }
+sub is_json  { (shift->_xs || return)->is_json  }
 sub is_sock  { (shift->_xs || return)->is_sock  }
+sub is_pres  { (shift->_xs || return)->is_pres  }
 sub is_pcap  { (shift->_xs || return)->is_pcap  }
 sub is_iface { (shift->_xs || return)->is_iface }
 
@@ -197,6 +199,17 @@ sub open_file {
   $self->_init_input($spec, $io, $xs, %opt);
 }
 
+sub open_json {
+  my($self, $spec, $fatal, %opt) = shift->_open_init(@_);
+  my $io;
+  eval { $io = $self->HANDLE_IO->open_input_file($spec, %opt) };
+  $@ && $self->error($@) && ($fatal ? croak $@ : return);
+  my $xs;
+  eval { $xs = $self->INPUT_XS->open_json($io) };
+  $@ && $self->error($@) && ($fatal ? croak $@ : return);
+  $self->_init_input($spec, $io, $xs, %opt);
+}
+
 sub open_sock {
   my $self = shift;
   my $spec = @_ % 2 ? shift : join('/', splice(@_, 0, 2));
@@ -213,6 +226,22 @@ sub open_sock {
   $self;
 }
 
+sub open_pres {
+  my($self, $spec, $fatal, %opt) = shift->_open_init(@_);
+  if (! $opt{filter_msgtype}) {
+    $self->error("filter_vendor and filter_msgtype required");
+    return unless $fatal;
+    croak $self->error;
+  }
+  my $io;
+  eval { $io = $self->HANDLE_IO->open_input_file($spec, %opt) };
+  $@ && $self->error($@) && ($fatal ? croak $@ : return);
+  my $xs;
+  eval { $xs = $self->INPUT_XS->open_pres($io, @{$opt{filter_msgtype}}) };
+  $@ && $self->error($@) && ($fatal ? croak $@ : return);
+  $self->_init_input($spec, $io, $xs, %opt);
+}
+
 sub open_pcap {
   my($self, $spec, $fatal, %opt) = shift->_open_init(@_);
   if (! $opt{filter_msgtype}) {
@@ -329,11 +358,18 @@ extension.
 
 =over 4
 
-=item open(%options)
+=item open($spec, %options)
 
-Creates a new input object. The class of the returned object depends on
-the apparent format of the input. The resulting object can be treated
-like an IO handle. The following both work:
+Creates a new input object from the given specification. A reasonable
+attempt is made to determine whether the specification is a file name
+(nmsg, pcap), file handle (nmsg), channel alias or socket specification
+(nmsg), or network device name (pcap), and is opened accordingly. If for
+some reason this reasonable guess is not so reasonable, use one of the
+specific open calls detailed below. The class of the returned object
+depends on the apparent format of the input.
+
+The resulting object can be treated like an IO handle. The following
+both work:
 
   while (my $msg = <$in>) {
     # deal with $msg
@@ -394,11 +430,20 @@ Promiscuous mode (live interface only)
 
 Opens an input in nmsg format, as specified by file name or file handle.
 
+=item open_json($spec, %options)
+
+Opens an input in JSON format, as specified by file name or file handle.
+
 =item open_sock($spec, %options)
 
 Opens an input socket as specified by "host/port" or socket handle.
 The host and port can also be passed as separate arguments.
 
+=item open_pres($spec, %options)
+
+Opens an input in nmsg presentation format, as specified by file name.
+The 'filter_vendor' and 'filter_msgtype' options are required.
+
 =item open_pcap($spec, %options)
 
 Opens an input in pcap format, as specified by file name. The
