@@ -201,6 +201,9 @@ sub clear_error { *shift->{_error} = undef }
 
 sub close {
   my $self  = shift;
+  # delete xs first in order to defer cleanup of unmanaged members
+  # e.g. destroy output xs before destroying rate objects
+  delete ${*$self}{_xs};
   %{*$self} = ();
   undef *$self if $] eq "5.008"; # cargo cult; see IO::String
   1;
