@@ -92,7 +92,6 @@ sub get_source         { shift->_get_xs_opt(source         => @_) }
 sub get_group          { shift->_get_xs_opt(group          => @_) }
 sub get_buffered       { shift->_get_xs_opt(buffered       => @_) }
 sub get_zlibout        { shift->_get_xs_opt(zlibout        => @_) }
-sub get_rate           { shift->_get_xs_opt(rate           => @_) }
 sub get_endline        { shift->_get_xs_opt(endline        => @_) }
 
 sub set_filter_msgtype { shift->_set_xs_opt(filter_msgtype => @_) }
@@ -103,6 +102,13 @@ sub set_buffered       { shift->_set_xs_opt(buffered       => @_) }
 sub set_zlibout        { shift->_set_xs_opt(zlibout        => @_) }
 sub set_endline        { shift->_set_xs_opt(endline        => @_) }
 
+sub get_rate {
+  my $self = shift;
+  my $r = $self->_get_xs_opt(rate => @_);
+  my($rate, $freq) = ($r->[0], $r->[1]);
+  wantarray ? ($rate, $freq) : [$rate, $freq];
+}
+
 sub set_rate {
   my $self = shift;
   my($rate, $freq);
@@ -112,7 +118,7 @@ sub set_rate {
   else {
     ($rate, $freq) = @_;
   }
-  $self->_set_xs_opt(rate => RATE_XS->init($rate, $freq))
+  $self->_set_xs_opt(rate => [$rate, $freq, RATE_XS->init($rate, $freq)])
 }
 
 ###
